# 当前版本
0.0.1

# 说明
- ATHENE: THE NLP Engine
- 准备给自己的原来写nlp工具起一个响亮的名字：为Athene，目前该包无任何代码。
- [原始包导航](https://pypi.org/project/nlpertools/)


## Emample

```python
import Athene
print("waiting......")
```


